abacusai.web_app_domain — AbacusAI documentation

# abacusai.web_app_domain

## Classes

`WebAppDomain` | Web App Domain

## Module Contents

class abacusai.web_app_domain.WebAppDomain(client, webAppDomainId=None, hostname=None, domainType=None, lifecycle=None, nameservers=None, dnsRecords=None, metadata=None, isRootDomain=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Web App Domain

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - webAppDomainId (id) – The ID of the web app domain

    - hostname (str) – The hostname of the web app domain

    - domainType (str) – The type of the web app domain

    - lifecycle (str) – The lifecycle of the web app domain

    - nameservers (list) – The nameservers of the web app domain

    - dnsRecords (list) – The DNS records of the web app domain

    - metadata (dict) – The metadata of the web app domain

    - isRootDomain (bool) – Whether the web app domain is a root domain

  web_app_domain_id = None
  hostname = None
  domain_type = None
  lifecycle = None
  nameservers = None
  dns_records = None
  metadata = None
  is_root_domain = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict